package com.jjt.biz.service;

import java.util.List;
import com.jjt.biz.domain.TwinDeviceAll;

/**
 * 全厂设备管理Service接口
 *
 * @author wukai
 * @date 2025-03-06
 */
public interface ITwinDeviceAllService {
    /**
     * 查询全厂设备管理
     *
     * @param deviceId 全厂设备管理主键
     * @return 全厂设备管理
     */
    public TwinDeviceAll selectTwinDeviceAllByDeviceId(Long deviceId);

    /**
     * 查询全厂设备管理列表
     *
     * @param twinDeviceAll 全厂设备管理
     * @return 全厂设备管理集合
     */
    public List<TwinDeviceAll> selectTwinDeviceAllList(TwinDeviceAll twinDeviceAll);

    /**
     * 新增全厂设备管理
     *
     * @param twinDeviceAll 全厂设备管理
     * @return 结果
     */
    public int insertTwinDeviceAll(TwinDeviceAll twinDeviceAll);

    /**
     * 修改全厂设备管理
     *
     * @param twinDeviceAll 全厂设备管理
     * @return 结果
     */
    public int updateTwinDeviceAll(TwinDeviceAll twinDeviceAll);

    /**
     * 批量删除全厂设备管理
     *
     * @param deviceIds 需要删除的全厂设备管理主键集合
     * @return 结果
     */
    public int deleteTwinDeviceAllByDeviceIds(Long[] deviceIds);

    /**
     * 删除全厂设备管理信息
     *
     * @param deviceId 全厂设备管理主键
     * @return 结果
     */
    public int deleteTwinDeviceAllByDeviceId(Long deviceId);
}
